#!/bin/bash

# https://pypi.debian.net/h5py/h5py-2.7.0.tar.gz

set -e

V=2.7.0
B=1

D=$PWD

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	cmd /c set >$TEMP/srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$TEMP/dstenv
	diff -u $TEMP/srcenv $TEMP/dstenv | sed -f $D/envdiff.sed >$TEMP/diffenv
	. $TEMP/diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $TEMP/srcenv $TEMP/dstenv $TEMP/diffenv
}

rm -rf ../build

for ARCH in x86_64 x86
do
	case "$ARCH" in
	x86)
		export OSGEO4W_ROOT="C:\\OSGeo4W"
		;;
	
	x86_64)
		export OSGEO4W_ROOT="C:\\OSGeo4W64"
		;;
	
	*)
		echo "Unsupported arch $ARCH" >&2
		exit 1
		;;
	esac

	for PY in Python27 Python36
	do
		export ARCH PY

		(
			fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
			if [ $PY == Python36 ]; then
				fetchenv $OSGEO4W_ROOT/bin/py3_env.bat
				pkg=python3-h5py
			else
				pkg=python-h5py
			fi

			cd ..

			export INCLUDE=$OSGEO4W_ROOT\\include
			export LIB=$OSGEO4W_ROOT\\lib

			type python
			python --version

			python setup.py build
			python setup.py install

			R=../../$ARCH/release/${pkg%-*}/$pkg

			mkdir -p $R
			egg=$(cd $OSGEO4W_ROOT/apps/$PY/Lib/site-packages; ls -1d h5py-$V-*.egg)
			echo $egg >$OSGEO4W_ROOT/apps/$PY/Lib/site-packages/h5py.pth
			tar --exclude="*.pyc" -C $(cygpath --mixed $OSGEO4W_ROOT) -cjf $R/$pkg-$V-$B.tar.bz2 \
				apps/$PY/Lib/site-packages/$egg \
				apps/$PY/Lib/site-packages/h5py.pth
			tar -cjf $R/$pkg-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/envdiff.sed

			cat <<EOF >$R/setup.hint
sdesc: "Read and write HDF5 files from Python"
ldesc: "Read and write HDF5 files from Python"
category: Libs
maintainer: JuergenFischer
requires: ${pkg%-*}-core hdf5
EOF
		)
	done
done


exit
